@@ -391,7 +391,10 @@ int ScriptCompiler::compile(const char *scrname)
 
 	ext = strrchr(token, '.');
 	if(ext)
-		*ext = 0;
+	{
+		if(strstr(exec_extensions, ext) == NULL)
+			*ext = 0;
+	}
 
 	return compile(scrname, token);
 }
@@ -475,6 +478,18 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	unsigned long addPmask = 0, subPmask = (unsigned long)~0;
 	unsigned long addPmask1 = 0, subPmask1 = (unsigned long)~0;
 	char catchname[256];
+	const char *embed = NULL;
+	bool mscmd = false, execflag = false;
+
+	if(strstr(".bat.cmd", cp))
+		mscmd = true;
+
+	if(strstr(exec_extensions, cp))
+	{
+		snprintf(namebuf, sizeof(namebuf), "%s::%s", exec_prefix, name);
+		name = namebuf;
+		embed = exec_token;
+	}
 
 	buffer = (char *)malloc(512);
 	bufsize = 512;
@@ -596,8 +611,21 @@ compile:
 
 			scrStream->getline(buffer + offset, bufsize - 1 - offset);
 			if(scrStream->eof())
-				break;
-
+			{
+				if(embed && !execflag)
+				{
+					execflag = true;
+					embed = NULL;
+					setString(buffer, 16, "exec");
+				}
+				else if(embed || (!total && !count && !offset))
+				{
+					embed = NULL;
+					setString(buffer, 16, exit_token);
+				}
+				else
+					break;
+			}
 			++lnum;
 			bp = strrchr(buffer, '\\');
 			if(bp)
@@ -605,12 +633,51 @@ compile:
 				++bp;
 				if(isspace(*bp) || !*bp)
 				{
-					offset = bp - buffer - 1;
+					if(!embed)
+						offset = bp - buffer - 1;
 					continue;
 				}
 			}
 
 			bp = buffer;
+			if(embed)
+			{
+				if(!mscmd)
+				{
+					if(*bp != '#')
+						continue;
+
+					++bp;
+					if(strnicmp(embed, bp, strlen(embed)))
+						continue;
+				}			
+
+				if(mscmd)
+				{
+					while(isspace(*bp))
+						++bp;
+
+					if(*bp == '@')
+						++bp;
+
+					if(stricmp(bp, "rem"))
+						continue;	
+
+					bp += 3;
+					while(isspace(*bp))
+						++bp;
+
+					if(strnicmp(embed, bp, strlen(embed)))
+						continue;
+				}
+				
+				bp += strlen(embed);
+				if(isalnum(*bp))
+				{
+					--bp;
+					*bp = ' ';
+				}
+			}			
 		}
 		else
 			then = false;
@@ -653,7 +720,7 @@ first:
 				break;
 			}
 
-			if(!cmds->ripple)
+			if(!cmds->ripple && !embed)
   			  if(!stricmp(token, "private") || !stricmp(token,
 "protected") || !stricmp(token, "public") || !stricmp(token, "program")
 || !stricmp(token, "state") || !stricmp(token, "module"))
@@ -689,27 +756,27 @@ repname1:
 			}
 
 
-			if(!stricmp(token, "service") && !cmds->ripple)
+			if(!stricmp(token, "service") && !cmds->ripple && !embed)
 			{
 				ftoken = "options";
 				pmode = "public";
 				goto repname1;
 			}
 
-			if(!strnicmp(token, "func", 4) && !cmds->ripple)
+			if(!strnicmp(token, "func", 4) && !cmds->ripple && !embed)
 			{
 				ftoken = "fconst";
 				pmode = "function";
 				goto repname1;
 			}
 
-			if(!strnicmp(token, "proc", 4) && !cmds->ripple)
+			if(!strnicmp(token, "proc", 4) && !cmds->ripple && !embed)
 			{
 				pmode = "function";
 				goto repname1;
 			}
 
-			if(!stricmp(token, "catch") && !cmds->ripple)
+			if(!stricmp(token, "catch") && !cmds->ripple && !embed)
 			{
 				ftoken = "fconst";
 				name = getToken();
@@ -803,9 +870,25 @@ repname1:
 		if(!token)
 			continue;
 
-		if(!stricmp(token, "::"))
+		if(!stricmp(token, "::") && !embed)
 			break;
 
+		if(!strnicmp(token, "exec.", 5) && embed)
+			execflag = true;
+
+		if(!stricmp(token, "exec") && embed)
+			execflag = true;
+
+		if(!strnicmp(token, "exec.", 5) && !execflag && exec_token)
+			goto noexec;		
+
+		if(!stricmp(token, "exec") && !execflag && exec_token)
+		{
+noexec:
+			slog.error("%s(%d): exec only used in embedded", filename, lnum);
+			continue;
+		}
+
 		if(!stricmp(token, "use"))
 		{
 			if(NULL != (token = getToken()))
