@@ -56,6 +56,15 @@
 #define	SCRIPT_TEMP_SPACE 16
 #define	SCRIPT_STACK_SIZE 32
 #define	SCRIPT_ROUTE_SLOTS 16
+#define	SCRIPT_EXEC_WRAPPER
+
+#ifndef CCXX_PACKING
+#if defined(__GNUC__)
+#define CCXX_PACKED
+#elif !defined(__hpux) && !defined(_AIX)
+#define CCXX_PACKED
+#endif
+#endif  
 
 namespace ost {
 
@@ -129,7 +138,7 @@ public:
 		char data[1];
 	}	Symbol;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef CCXX_PACKED
 #pragma	pack(1)
 #endif
 
@@ -138,7 +147,7 @@ public:
 		unsigned short head, tail, rec, count;
 	}	Array;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack()
 #endif
 
@@ -256,6 +265,10 @@ public:
 	static const char *access_user;
 	static const char *access_pass;
 	static const char *access_host;
+	static const char *exec_extensions;
+	static const char *exec_token;
+	static const char *exec_prefix;
+	static const char *exit_token;
 
         static void addFunction(const char *name, unsigned count, Function i);
         static void addConditional(const char *name, Cond test);
@@ -306,7 +319,7 @@ private:
 	friend class __EXPORT ScriptCompiler;
 	friend class __EXPORT ScriptBinder;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack(1)
 #endif
 
@@ -319,7 +332,7 @@ private:
 		char keyword[1];
 	}	Keyword;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack()
 #endif
 
