@@ -128,18 +128,26 @@ ScriptCompiler(&_image, "/ccscript/define")
 Script::Name *shCompiler::getScript(const char *name)
 {
 	static bool started = false;
-	char fname[128];
+	char fname[128], lname[128];
+	const char *ext;
 	Name *line = ScriptImage::getScript(name);
 	if(!line)
 	{
 		strcpy(fname, name);
-		strcat(fname, ".scr");
+		ext = strrchr(name, '.');
+		if(!ext)
+			strcat(fname, ".scr");
 		if(!canAccess(fname) && !started)
 		{
 			cerr << "testscript: " << fname << ": cannot execute" << endl;
 			::exit(-1);
 		}
 		compile(fname);
+		if(ext && stricmp(ext, ".scr"))
+		{
+			snprintf(lname, sizeof(lname), "exec::%s", name);
+			name = lname;
+		} 
 		line = ScriptImage::getScript(name);
 		if(!line && !started)
 		{
@@ -320,7 +328,9 @@ int main(int argc, char **argv)
 	char *ext;
 	int stepper;
 	char argname[10];
+	char lname[128];
 	int argcount = 0;
+	char *name;
 
 	if(argc < 2)
 		::exit(-1);
@@ -347,9 +357,16 @@ int main(int argc, char **argv)
 
 	slog("testscript", Slog::classUser, Slog::levelInfo);
 
-	shCompiler.getScript(argv[1]);
+	name = argv[1];
+	shCompiler.getScript(name);
+	
+	if(ext && *ext)
+	{
+		snprintf(lname, sizeof(lname), "exec::%s", name);
+		name = lname;
+	}
 
-	if(!interp.attach(&_image, argv[1]))
+	if(!interp.attach(&_image, name))
 		::exit(-1);
 
 	while(argcount < argc)
